#include "colored_log_ctrl.h"

ColoredLogCtrl::ColoredLogCtrl(wxWindow* parent)
	: wxTextCtrl(parent, wxID_ANY, wxEmptyString,
				wxDefaultPosition, wxDefaultSize,
				wxTE_MULTILINE | wxTE_READONLY | wxTE_RICH2) {
	SetFont(wxFont(10, wxFONTFAMILY_TELETYPE, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL));
}

void ColoredLogCtrl::LogMessage(const wxString& message, const wxColour& color) {
	// 获取当前文本长度
	long start = GetLastPosition();

	// 添加时间戳和消息
	wxString timeStamp = wxDateTime::Now().Format("%Y-%m-%d %H:%M:%S: ");
	AppendText(timeStamp + message + "\n");

	// 设置颜色
	SetStyle(start, GetLastPosition(), wxTextAttr(color));

	// 滚动到底部
	ShowPosition(GetLastPosition());
}

void ColoredLogCtrl::LogError(const wxString& message) {
	LogMessage(message, *wxRED);
}

void ColoredLogCtrl::LogWarning(const wxString& message) {
	LogMessage(message, wxColour(255, 140, 0));  // 橙色
}

void ColoredLogCtrl::LogInfo(const wxString& message) {
	LogMessage(message, *wxBLUE);
}

void ColoredLogCtrl::LogSuccess(const wxString& message) {
	LogMessage(message, wxColour(0, 128, 0));  // 绿色
}
