#include "config_manager.h"
#include <fstream>
#include <iostream>

ConfigManager& ConfigManager::Instance() {
	static ConfigManager instance;
	return instance;
}

bool ConfigManager::Load(const std::string& file_path) {
	// 检查文件是否存在
	std::ifstream file(file_path);
	if (!file.good()) {
		// 文件不存在或无法访问
		InitializeDefaultConfig();
		return false;
	}
	file.close();

	// 加载配置文件
	SI_Error result = ini_.LoadFile(file_path.c_str());
	if (result < 0) {
		// 加载失败
		InitializeDefaultConfig();
		return false;
	}

	return true;
}

bool ConfigManager::Save(const std::string& file_path) {
	SI_Error result = ini_.SaveFile(file_path.c_str());
	return result >= 0;
}

void ConfigManager::InitializeDefaultConfig() {
	// 设置默认值
	ini_.SetValue("settings", "repo_path", "");
	ini_.SetBoolValue("settings", "hard_reset", false);
}

std::string ConfigManager::GetRepositoryPath() const {
	return ini_.GetValue("settings", "repo_path", "");
}

void ConfigManager::SetRepositoryPath(const std::string& path) {
	ini_.SetValue("settings", "repo_path", path.c_str());
}

bool ConfigManager::GetHardReset() const {
	return ini_.GetBoolValue("settings", "hard_reset", false);
}

void ConfigManager::SetHardReset(bool value) {
	ini_.SetBoolValue("settings", "hard_reset", value);
}

void ConfigManager::SaveBranchToGroup(const std::string& group_name, const std::string& repo_name, const std::string& branch_name) {
	ini_.SetValue(group_name.c_str(), repo_name.c_str(), branch_name.c_str());
}

std::string ConfigManager::GetBranchFromGroup(const std::string& group_name, const std::string& repo_name, const std::string& default_branch, bool* found) {
	const char* value = ini_.GetValue(group_name.c_str(), repo_name.c_str(), default_branch.c_str());
	if (found) {
		*found = (value != default_branch.c_str());  // 检查是否使用了默认值
	}
	return value;
}
