#pragma once
#include <wx/wx.h>
#include <memory>
#include <vector>
#include "git_repository.h"
#include "colored_log_ctrl.h"

// 分支选择器组件
class BranchSelector : public wxPanel {
public:
	BranchSelector(wxWindow* parent, std::shared_ptr<git::Repository> repo, const wxString& label = wxEmptyString);

	bool SelectBranch(const wxString& branch_name);
	bool SelectGroupBranch(const wxString& group_name);
	std::string GetSelectedBranchName() const;
	bool ApplyBranchChange(bool hard_reset);

	auto GetRepo() const { return repo_; }
private:
	void OnBranchSelected(wxCommandEvent& event);

	wxComboBox* branch_combo_ = nullptr;
	std::shared_ptr<git::Repository> repo_;
	wxString current_group_;

	wxDECLARE_EVENT_TABLE();
};

// 主窗口
class MainFrame : public wxFrame {
public:
	explicit MainFrame(const wxString& title);
	~MainFrame() override = default;

private:
	void OnApply(wxCommandEvent& event);
	void OnGroupSelect(wxCommandEvent& event);
	void OnHardResetChanged(wxCommandEvent& event);

	void InitializeUI();
	void PopulateBranchGroups();

	std::vector<BranchSelector*> branch_selectors_;
	wxComboBox* group_combo_ = nullptr;
	wxCheckBox* hard_reset_checkbox_ = nullptr;
	ColoredLogCtrl* log_ctrl_ = nullptr;

	std::shared_ptr<git::Repository> main_repo_;
	bool is_hard_reset_ = false;

	wxDECLARE_EVENT_TABLE();
};
